@@ -1,7 +1,7 @@
 #
 #       plot.fv.R   (was: conspire.S)
 #
-#  $Revision: 1.142 $    $Date: 2023/07/09 09:40:40 $
+#  $Revision: 1.144 $    $Date: 2025/02/04 00:25:40 $
 #
 #
 
@@ -57,7 +57,7 @@ plot.fv <- local({
                       shade=fvnames(x, ".s"), shadecol="grey", add=FALSE,
                       log="",
                       mathfont=c("italic", "plain", "bold", "bolditalic"), 
-                      limitsonly=FALSE) {
+                      limitsonly=FALSE, do.plot=TRUE) {
 
     xname <-
       if(is.language(substitute(x))) short.deparse(substitute(x)) else ""
@@ -416,8 +416,10 @@ plot.fv <- local({
 
     ## ------------------ start plotting ---------------------------
 
+    do.plot <- isTRUE(do.plot)
+    
     ## create new plot
-    if(!add)
+    if(do.plot && !add)
       do.call(plot.default,
               resolve.defaults(list(xlim, ylim, type="n", log=log),
                                list(xlab=xlab, ylab=ylab),
@@ -507,9 +509,11 @@ plot.fv <- local({
   
     ## ----------------- plot lines ------------------------------
 
-    for(i in allind) {
-      clip.to.usr(xlogscale, ylogscale)
-      lines(rhsdata, lhsdata[,i], lty=lty[i], col=col[i], lwd=lwd[i])
+    if(do.plot) {
+      for(i in allind) {
+        clip.to.usr(xlogscale, ylogscale)
+        lines(rhsdata, lhsdata[,i], lty=lty[i], col=col[i], lwd=lwd[i])
+      }
     }
 
     if(nplots == 1)
@@ -555,7 +559,7 @@ plot.fv <- local({
 
     ## --------------- handle legend plotting  -----------------------------
     
-    if(identical(legend, TRUE)) {
+    if(do.plot && isTRUE(legend)) {
       ## legend will be plotted
       ## Basic parameters of legend
       legendxpref <- if(identical(legendpos, "float")) NULL else legendpos
@@ -645,7 +649,7 @@ assemble.plot.objects <- function(xlim, ylim, ..., lines=NULL, polygon=NULL) {
         lines <- list(lines)
       } else if(!all(unlist(lapply(lines, checkfields, L=c("x", "y")))))
         stop("lines should be a psp object, a list(x,y) or a list of list(x,y)")
-      W <- owin(xlim, ylim)
+      W <- owinInternalRect(xlim, ylim)
       for(i in seq_along(lines)) {
         lines.i <- lines[[i]]
         x.i <- lines.i$x
@@ -737,7 +741,8 @@ findbestlegendpos <- local({
         legout <- do.call(graphics::legend,
                           append(legendspec, list(plot=FALSE)))
         ## determine bounding box
-        legbox <- with(legout$rect, owin(c(left, left+w), c(top-h, top)))
+        legbox <- with(legout$rect, 
+                       owinInternalRect(c(left, left+w), c(top-h, top)))
         scaledlegbox <- affine(legbox, mat=mat)
         ## check for collision 
         Dmin <- min(D[scaledlegbox])
